/* splash.c the splash screen when the game is first run.
 *
 * Copyright (c) 2019, Chris Camacho (codifies) http://bedroomcoders.co.uk/captcha/
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *      * Redistributions of source code must retain the above copyright
 *        notice, this list of conditions and the following disclaimer.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
 * IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
 * OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#include <stdlib.h>

#include "raylib.h"

#include "screens.h"

static int frames;
static bool logoDone;

static Sound typing;
static Texture2D logo;
static ScreenCallbacks* scb; // structure of callbacks for this screen
static float sceneAlpha;

static void update()
{
    frames++;
    if (frames > 260) {
        logoDone = true;
    }

    if (frames == 40) {
        PlaySound(typing);
    }

    sceneAlpha = 1.0;
    if (frames < 240) {
        sceneAlpha = frames / 240.0;
    }
}

static void render(fnt* font)
{
    ClearBackground(WHITE);

    DrawTexture(logo, gameScreenWidth / 2 - logo.width / 2.0,
                        gameScreenHeight * 0.6, Fade(WHITE, sceneAlpha));

    DrawRectangle(gameScreenWidth - 272, gameScreenHeight - 272, 256, 256,
                        Fade(BLACK, sceneAlpha));
    DrawRectangle(gameScreenWidth - 256, gameScreenHeight - 256, 224, 224, RAYWHITE);
    DrawText("raylib", gameScreenWidth - 196, gameScreenHeight - 96, 50,
                        Fade(BLACK, sceneAlpha));

    BeginShaderMode(font->fontShader);    // Activate SDF font shader
        DrawTextEx(font->font, "bedroomcoders.co.uk", (Vector2){677,800}, 40, -1,
                        Fade(BLACK, sceneAlpha));
    EndShaderMode();            // Activate our default shader for next drawings

}

static bool done()
{
    return logoDone;
}

static void destroy()
{
    UnloadTexture(logo);
    UnloadSound(typing);
    free(scb);
}

ScreenCallbacks* setUpSplash()
{
    scb = malloc(sizeof(ScreenCallbacks));
    scb->update = update;
    scb->render = render;
    scb->destroy = destroy;
    scb->done = done;

    frames = 0;
    logoDone = false;

    logo = LoadTexture("data/programmer.png");
    typing = LoadSound("data/typing.wav");

    return scb;
}
